@@ -7,19 +7,15 @@
 var LibraryStackTrace = {
   $jsStackTrace: () => new Error().stack.toString(),
 
-  $getCallstack__deps: ['$jsStackTrace', '$warnOnce'],
+  $getCallstack__deps: ['$jsStackTrace',
+#if ASSERTIONS
+    '$warnOnce'
+#endif
+  ],
   $getCallstack__docs: '/** @param {number=} flags */',
   $getCallstack: (flags) => {
     var callstack = jsStackTrace();
 
-    // Find the symbols in the callstack that corresponds to the functions that
-    // report callstack information, and remove everything up to these from the
-    // output.
-    var iThisFunc = callstack.lastIndexOf('_emscripten_log');
-    var iThisFunc2 = callstack.lastIndexOf('_emscripten_get_callstack');
-    var iNextLine = callstack.indexOf('\n', Math.max(iThisFunc, iThisFunc2))+1;
-    callstack = callstack.slice(iNextLine);
-
 #if ASSERTIONS
     if (flags & {{{ cDefs.EM_LOG_C_STACK }}}) {
       warnOnce('emscripten_log with EM_LOG_C_STACK no longer has any effect');
@@ -65,6 +61,14 @@ var LibraryStackTrace = {
         }
       }
 
+      // Find the symbols in the callstack that corresponds to the functions that
+      // report callstack information, and remove everything up to these from the
+      // output.
+      if (symbolName == '_emscripten_log' || symbolName == '_emscripten_get_callstack') {
+        callstack = '';
+        continue;
+      }
+
       if ((flags & {{{ cDefs.EM_LOG_C_STACK | cDefs.EM_LOG_JS_STACK }}})) {
         if (flags & {{{ cDefs.EM_LOG_NO_PATHS }}}) {
           file = file.substring(file.replace(/\\/g, "/").lastIndexOf('/')+1);
@@ -101,7 +105,7 @@ var LibraryStackTrace = {
     abort('Cannot use convertFrameToPC (needed by __builtin_return_address) without -sUSE_OFFSET_CONVERTER');
 #else
 #if ASSERTIONS
-    assert(wasmOffsetConverter);
+    assert(wasmOffsetConverter, 'wasmOffsetConverter global not found');
 #endif
     var match;
 
@@ -271,7 +275,7 @@ var LibraryStackTrace = {
 #endif
   },
 
-  $convertPCtoSourceLocation__deps: ['$UNWIND_CACHE', '$convertFrameToPC'],
+  $convertPCtoSourceLocation__deps: ['$UNWIND_CACHE'],
   $convertPCtoSourceLocation: (pc) => {
     if (UNWIND_CACHE.last_get_source_pc == pc) return UNWIND_CACHE.last_source;
 
