@@ -71,6 +71,8 @@ passing_core_test_modes = [
   'wasm64',
   'wasm64_v8',
   'wasm64_4gb',
+  'esm_integration',
+  'instance',
 ]
 
 # The default core test mode, used when none is specified
