@@ -30,7 +30,6 @@ from tools import webassembly
 from tools import extract_metadata
 from tools.utils import exit_with_error, path_from_root, removeprefix
 from tools.shared import DEBUG, asmjs_mangle, in_temp
-from tools.shared import treat_as_user_export
 from tools.settings import settings, user_settings
 
 sys.path.append(path_from_root('third_party'))
@@ -41,16 +40,7 @@ logger = logging.getLogger('emscripten')
 # helper functions for JS to call into C to do memory operations. these
 # let us sanitize memory access from the JS side, by calling into C where
 # it has been instrumented.
-ASAN_C_HELPERS = [
-  '_asan_c_load_1', '_asan_c_load_1u',
-  '_asan_c_load_2', '_asan_c_load_2u',
-  '_asan_c_load_4', '_asan_c_load_4u',
-  '_asan_c_load_f', '_asan_c_load_d',
-  '_asan_c_store_1', '_asan_c_store_1u',
-  '_asan_c_store_2', '_asan_c_store_2u',
-  '_asan_c_store_4', '_asan_c_store_4u',
-  '_asan_c_store_f', '_asan_c_store_d',
-]
+ASAN_C_HELPERS = ['__asan_loadN', '__asan_storeN']
 
 
 def maybe_disable_filesystem(imports):
@@ -279,10 +269,14 @@ def trim_asm_const_body(body):
   return body
 
 
+def create_other_export_declarations(tag_exports):
+  return '\n'.join(f'var {asmjs_mangle(name)};' for name in tag_exports)
+
+
 def create_global_exports(global_exports):
   lines = []
   for k, v in global_exports.items():
-    if building.is_internal_global(k):
+    if shared.is_internal_global(k):
       continue
 
     v = int(v)
@@ -416,11 +410,13 @@ def emscript(in_wasm, out_wasm, outfile_js, js_syms, finalize=True, base_metadat
 
   if base_metadata:
     function_exports = base_metadata.function_exports
+    tag_exports = base_metadata.tag_exports
     # We want the real values from the final metadata but we only want to
     # include names from the base_metadata.  See phase_link() in link.py.
     global_exports = {k: v for k, v in metadata.global_exports.items() if k in base_metadata.global_exports}
   else:
     function_exports = metadata.function_exports
+    tag_exports = metadata.tag_exports
     global_exports = metadata.global_exports
 
   if settings.ASYNCIFY == 1:
@@ -430,13 +426,7 @@ def emscript(in_wasm, out_wasm, outfile_js, js_syms, finalize=True, base_metadat
     function_exports['asyncify_stop_rewind'] = webassembly.FuncType([], [])
 
   parts = [pre]
-  receiving = create_receiving(function_exports)
-  if settings.WASM_ESM_INTEGRATION:
-    sending = create_sending(metadata, forwarded_json['librarySymbols'])
-    reexports = create_reexports()
-    parts += [sending, receiving, reexports]
-  else:
-    parts += create_module(receiving, metadata, global_exports, forwarded_json['librarySymbols'])
+  parts += create_module(metadata, function_exports, global_exports, tag_exports, forwarded_json['librarySymbols'])
   parts.append(post)
 
   full_js_module = ''.join(parts)
@@ -571,7 +561,7 @@ def finalize_wasm(infile, outfile, js_syms):
   # EMSCRIPTEN_KEEPALIVE (llvm.used).
   # These are any exports that were not requested on the command line and are
   # not known auto-generated system functions.
-  unexpected_exports = [e for e in metadata.all_exports if treat_as_user_export(e)]
+  unexpected_exports = [e for e in metadata.all_exports if shared.is_user_export(e)]
   for n in unexpected_exports:
     if not n.isidentifier():
       exit_with_error(f'invalid export name: {n}')
@@ -754,10 +744,15 @@ def create_em_js(metadata):
     arg_names = [arg.split()[-1].replace('*', '') for arg in args if arg]
     args = ','.join(arg_names)
     func = f'function {name}({args}) {body}'
+    if settings.WASM_ESM_INTEGRATION:
+      # Like JS library function EM_JS functions are exported at the point of
+      # declaration in WASM_ESM_INTEGRATION node.
+      func = f'export {func}'
+    em_js_funcs.append(func)
     if (settings.MAIN_MODULE or settings.ASYNCIFY == 2) and name in metadata.em_js_func_types:
       sig = func_type_to_sig(metadata.em_js_func_types[name])
-      func = func + f'\n{name}.sig = \'{sig}\';'
-    em_js_funcs.append(func)
+      sig = f'{name}.sig = \'{sig}\';'
+      em_js_funcs.append(sig)
 
   return em_js_funcs
 
@@ -825,7 +820,10 @@ def create_sending(metadata, library_symbols):
 
   for name in metadata.imports:
     if name in metadata.em_js_funcs:
-      send_items_map[name] = name
+      # EM_JS functions are exported directly at the declaration site in
+      # WASM_ESM_INTEGRATION mode.
+      if not settings.WASM_ESM_INTEGRATION:
+        send_items_map[name] = name
     else:
       send_items_map[name] = asmjs_mangle(name)
 
@@ -880,16 +878,18 @@ def create_sending(metadata, library_symbols):
   return '{\n  ' + ',\n  '.join(elems) + '\n}'
 
 
-def create_reexports():
+def create_reexports(metadata):
   assert settings.WASM_ESM_INTEGRATION
   exports = '// Re-export imported wasm functions to the JS entry point. These are user-facing and underscore mangled.\n'
   wasm_exports = []
   for exp in building.user_requested_exports:
     if shared.is_c_symbol(exp):
       demangled = shared.demangle_c_symbol_name(exp)
-      if demangled in settings.WASM_EXPORTS:
+      if demangled in metadata.em_js_funcs:
+        wasm_exports.append(f'{demangled} as {exp}')
+      elif demangled in settings.WASM_EXPORTS:
         wasm_exports.append(exp)
-      if demangled == 'main' and '__main_argc_argv' in settings.WASM_EXPORTS:
+      elif demangled == 'main' and '__main_argc_argv' in settings.WASM_EXPORTS:
         wasm_exports.append('_main')
   exports += f"export {{ {', '.join(wasm_exports)} }};\n\n"
   return exports
@@ -961,23 +961,26 @@ def make_export_wrappers(function_exports):
   return wrappers
 
 
-def create_receiving(function_exports):
+def create_receiving(function_exports, tag_exports):
+  receiving = ['// Imports from the Wasm binary.']
+
   if settings.WASM_ESM_INTEGRATION:
-    exports = [f'{f} as {asmjs_mangle(f)}' for f in function_exports]
+    exports = tag_exports + list(function_exports.keys())
+    exports = [f'{f} as {asmjs_mangle(f)}' for f in exports]
     if not settings.IMPORTED_MEMORY:
       exports.append('memory as wasmMemory')
     if not settings.RELOCATABLE:
       exports.append('__indirect_function_table as wasmTable')
-    exports = ',\n  '.join(exports)
-    return f"import {{\n  {exports}\n}} from './{settings.WASM_BINARY_FILE}';\n\n"
+    receiving.append('import {')
+    receiving.append('  ' + ',\n  '.join(exports))
+    receiving.append(f"}} from './{settings.WASM_BINARY_FILE}';")
+    return '\n'.join(receiving) + '\n\n'
 
   # When not declaring asm exports this section is empty and we instead programmatically export
   # symbols on the global object by calling exportWasmSymbols after initialization
   if not settings.DECLARE_ASM_MODULE_EXPORTS:
     return ''
 
-  receiving = []
-
   if settings.MINIMAL_RUNTIME:
     # Exports are assigned inside a function to variables
     # existing in top level JS scope, i.e.
@@ -1005,44 +1008,57 @@ def create_receiving(function_exports):
   return '\n'.join(receiving) + '\n'
 
 
-def create_module(receiving, metadata, global_exports, library_symbols):
-  receiving += create_global_exports(global_exports)
+def create_module(metadata, function_exports, global_exports, tag_exports,library_symbols):
   module = []
 
+  receiving = create_receiving(function_exports, tag_exports)
+  receiving += create_global_exports(global_exports)
   sending = create_sending(metadata, library_symbols)
-  if settings.PTHREADS or settings.WASM_WORKERS:
-    sending = textwrap.indent(sending, '  ').strip()
-    module.append('''\
-var wasmImports;
-function assignWasmImports() {
-  wasmImports = %s;
-}
-''' % sending)
-  else:
-    module.append('var wasmImports = %s;\n' % sending)
 
-  if not settings.MINIMAL_RUNTIME:
-    if settings.MODULARIZE == 'instance':
-      module.append("var wasmExports;\n")
-    elif settings.WASM_ASYNC_COMPILATION:
-      if can_use_await():
-        # In modularize mode the generated code is within a factory function.
-        # This magic string gets replaced by `await createWasm`.  It needed to allow
-        # closure and acorn to process the module without seeing this as a top-level
-        # await.
-        module.append("var wasmExports = EMSCRIPTEN$AWAIT(createWasm());\n")
-      else:
-        module.append("var wasmExports;\ncreateWasm();\n")
+  if settings.WASM_ESM_INTEGRATION:
+    module.append(sending)
+  else:
+    receiving += create_other_export_declarations(tag_exports)
+
+    if settings.PTHREADS or settings.WASM_WORKERS or (settings.IMPORTED_MEMORY and settings.MODULARIZE == 'instance'):
+      sending = textwrap.indent(sending, '  ').strip()
+      module.append('''\
+  var wasmImports;
+  function assignWasmImports() {
+    wasmImports = %s;
+  }
+  ''' % sending)
     else:
-      module.append("var wasmExports = createWasm();\n")
+      module.append('var wasmImports = %s;\n' % sending)
+
+    if not settings.MINIMAL_RUNTIME:
+      if settings.MODULARIZE == 'instance':
+        module.append("var wasmExports;\n")
+      elif settings.WASM_ASYNC_COMPILATION:
+        if can_use_await():
+          # In modularize mode the generated code is within a factory function.
+          # This magic string gets replaced by `await createWasm`.  It needed to allow
+          # closure and acorn to process the module without seeing this as a top-level
+          # await.
+          module.append("var wasmExports = EMSCRIPTEN$AWAIT(createWasm());\n")
+        else:
+          module.append("var wasmExports;\ncreateWasm();\n")
+      else:
+        module.append("var wasmExports = createWasm();\n")
 
   module.append(receiving)
+
   if settings.SUPPORT_LONGJMP == 'emscripten' or not settings.DISABLE_EXCEPTION_CATCHING:
     module.append(create_invoke_wrappers(metadata))
   else:
     assert not metadata.invoke_funcs, "invoke_ functions exported but exceptions and longjmp are both disabled"
+
   if settings.MEMORY64 or settings.CAN_ADDRESS_2GB:
     module.append(create_pointer_conversion_wrappers(metadata))
+
+  if settings.WASM_ESM_INTEGRATION:
+    module.append(create_reexports(metadata))
+
   return module
 
 
@@ -1154,7 +1170,7 @@ def create_pointer_conversion_wrappers(metadata):
     mapping[sym] = sig
 
   for f in ASAN_C_HELPERS:
-    mapping[f] = '_p'
+    mapping[f] = '_pp'
 
   wrappers = '''
 // Argument name here must shadow the `wasmExports` global so
